View source: R/modelExecutorUI.R
| modelExecutorUI | R Documentation |
Used to execute a model developed in Certara.RsNLME from a Shiny GUI.
modelExecutorUI(
model,
hosts,
wd,
outputfile = "shiny_dirs.txt",
metamodelFileName = "temp.mmdl",
fromPirana = FALSE
)
model |
Model object generated from |
hosts |
One or more hosts generated from |
wd |
Working directory where the model output folders will be created.
If missing, the directory specified in the model object will be used |
outputfile |
Text file providing a list of model output subfolders generated inside |
metamodelFileName |
Name of the resulting metamodel to generate. Only applicable for Pirana. |
fromPirana |
Logical; set to |
Deploys a Shiny app to execute a Certara.RsNLME model. Returns NULL if assigned to an object.
if (interactive()) {
model <- Certara.RsNLME::pkmodel(
parameterization = "Clearance",
absorption = "Intravenous",
numCompartments = 2,
data = Certara.RsNLME::pkData,
ID = "Subject",
A1 = "Amount",
Time = "Act_Time",
CObs = "Conc",
modelName = "pk_model")
modelExecutorUI(model)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.